@@ -17,12 +17,12 @@
 
 Example:
 
-.. literalinclude::  /../../tests/yamlparser/fixtures/general-example-001.yaml
+.. literalinclude::  /../../tests/yamlparser/job_fixtures/general-example-001.yaml
 
 :Job Parameters:
     * **project-type**:
       Defaults to "freestyle", but "maven" as well as "multijob", "flow",
-      "workflow" or "externaljob" can also be specified.
+      "pipeline" or "externaljob" can also be specified.
 
     * **defaults**:
       Specifies a set of :ref:`defaults` to use for this job, defaults to
@@ -56,6 +56,13 @@ Example:
       Path for a custom workspace. Defaults to Jenkins default
       configuration.
 
+    * **folder**:
+      The folder attribute provides an alternative to using '<path>/<name>' as
+      the job name to specify which Jenkins folder to upload the job to.
+
+      Requires the Jenkins :jenkins-plugins:`CloudBees Folders Plugin
+      <cloudbees-folder>`.
+
     * **child-workspace**:
       Path for a child custom workspace. Defaults to Jenkins default
       configuration. This parameter is only valid for matrix type jobs.
@@ -97,10 +104,12 @@ Example:
       **Deprecated on jenkins >=1.637**: use the ``build-discarder``
       property instead
 
+    * **jdk**:
+      The name of the jdk to use
+
     * **raw**:
       If present, this section should contain a single **xml** entry. This XML
       will be inserted at the top-level of the :ref:`Job` definition.
-
 """
 
 import logging
@@ -114,85 +123,99 @@ class General(jenkins_jobs.modules.base.Base):
     sequence = 10
     logrotate_warn_issued = False
 
-    def gen_xml(self, parser, xml, data):
-        jdk = data.get('jdk', None)
+    def gen_xml(self, xml, data):
+        jdk = data.get("jdk", None)
         if jdk:
-            XML.SubElement(xml, 'jdk').text = jdk
-        XML.SubElement(xml, 'actions')
-        desc_text = data.get('description', None)
+            XML.SubElement(xml, "jdk").text = jdk
+        XML.SubElement(xml, "actions")
+        desc_text = data.get("description", None)
         if desc_text is not None:
-            description = XML.SubElement(xml, 'description')
+            description = XML.SubElement(xml, "description")
             description.text = desc_text
-        XML.SubElement(xml, 'keepDependencies').text = 'false'
-        disabled = data.get('disabled', None)
-        if disabled is not None:
-            if disabled:
-                XML.SubElement(xml, 'disabled').text = 'true'
-            else:
-                XML.SubElement(xml, 'disabled').text = 'false'
-        if 'display-name' in data:
-            XML.SubElement(xml, 'displayName').text = data['display-name']
-        if data.get('block-downstream'):
-            XML.SubElement(xml,
-                           'blockBuildWhenDownstreamBuilding').text = 'true'
-        else:
-            XML.SubElement(xml,
-                           'blockBuildWhenDownstreamBuilding').text = 'false'
-        if data.get('block-upstream'):
-            XML.SubElement(xml,
-                           'blockBuildWhenUpstreamBuilding').text = 'true'
-        else:
-            XML.SubElement(xml,
-                           'blockBuildWhenUpstreamBuilding').text = 'false'
-        if 'auth-token' in data:
-            XML.SubElement(xml, 'authToken').text = data['auth-token']
-        if data.get('concurrent'):
-            XML.SubElement(xml, 'concurrentBuild').text = 'true'
-        else:
-            XML.SubElement(xml, 'concurrentBuild').text = 'false'
-        if 'workspace' in data:
-            XML.SubElement(xml, 'customWorkspace').text = \
-                str(data['workspace'])
-        if (xml.tag == 'matrix-project') and ('child-workspace' in data):
-            XML.SubElement(xml, 'childCustomWorkspace').text = \
-                str(data['child-workspace'])
-        if 'quiet-period' in data:
-            XML.SubElement(xml, 'quietPeriod').text = str(data['quiet-period'])
-        node = data.get('node', None)
-        if node:
-            XML.SubElement(xml, 'assignedNode').text = node
-            XML.SubElement(xml, 'canRoam').text = 'false'
-        else:
-            XML.SubElement(xml, 'canRoam').text = 'true'
-        if 'retry-count' in data:
-            XML.SubElement(xml, 'scmCheckoutRetryCount').text = \
-                str(data['retry-count'])
+        XML.SubElement(xml, "keepDependencies").text = "false"
 
-        if 'logrotate' in data:
+        # Need to ensure we support the None parameter to allow disabled to
+        # remain the last setting if the user purposely adds and then removes
+        # the disabled parameter.
+        # See: http://lists.openstack.org/pipermail/openstack-infra/2016-March/003980.html  # noqa
+        disabled = data.get("disabled", None)
+        if disabled is not None:
+            XML.SubElement(xml, "disabled").text = str(disabled).lower()
+
+        if "display-name" in data:
+            XML.SubElement(xml, "displayName").text = data["display-name"]
+        if data.get("project-type", "freestyle") != "pipeline":
+            if data.get("block-downstream"):
+                XML.SubElement(xml, "blockBuildWhenDownstreamBuilding").text = "true"
+            else:
+                XML.SubElement(xml, "blockBuildWhenDownstreamBuilding").text = "false"
+            if data.get("block-upstream"):
+                XML.SubElement(xml, "blockBuildWhenUpstreamBuilding").text = "true"
+            else:
+                XML.SubElement(xml, "blockBuildWhenUpstreamBuilding").text = "false"
+        authtoken = data.get("auth-token", None)
+        if authtoken is not None:
+            XML.SubElement(xml, "authToken").text = authtoken
+        if data.get("project-type", "freestyle") != "pipeline":
+            if data.get("concurrent"):
+                XML.SubElement(xml, "concurrentBuild").text = "true"
+            else:
+                XML.SubElement(xml, "concurrentBuild").text = "false"
+        else:
+            if not data.get("concurrent"):
+                properties = xml.find("properties")
+                if properties is None:
+                    properties = XML.SubElement(xml, "properties")
+                XML.SubElement(
+                    properties,
+                    "org.jenkinsci.plugins.workflow.job.properties.DisableConcurrentBuildsJobProperty",
+                )
+        if data.get("project-type", "freestyle") != "pipeline":
+            if "workspace" in data:
+                XML.SubElement(xml, "customWorkspace").text = str(data["workspace"])
+        if (xml.tag == "matrix-project") and ("child-workspace" in data):
+            XML.SubElement(xml, "childCustomWorkspace").text = str(
+                data["child-workspace"]
+            )
+        if "quiet-period" in data:
+            XML.SubElement(xml, "quietPeriod").text = str(data["quiet-period"])
+        node = data.get("node", None)
+        if data.get("project-type", "freestyle") != "pipeline":
+            if node:
+                XML.SubElement(xml, "assignedNode").text = node
+                XML.SubElement(xml, "canRoam").text = "false"
+            else:
+                XML.SubElement(xml, "canRoam").text = "true"
+        if "retry-count" in data:
+            XML.SubElement(xml, "scmCheckoutRetryCount").text = str(data["retry-count"])
+
+        if "logrotate" in data:
             if not self.logrotate_warn_issued:
-                logging.warn('logrotate is deprecated on jenkins>=1.637, use '
-                             'the property build-discarder on newer jenkins '
-                             'instead')
+                logging.warning(
+                    "logrotate is deprecated on jenkins>=1.637,"
+                    " the property build-discarder on newer"
+                    " jenkins instead"
+                )
                 self.logrotate_warn_issued = True
 
-            lr_xml = XML.SubElement(xml, 'logRotator')
-            logrotate = data['logrotate']
-            lr_days = XML.SubElement(lr_xml, 'daysToKeep')
-            lr_days.text = str(logrotate.get('daysToKeep', -1))
-            lr_num = XML.SubElement(lr_xml, 'numToKeep')
-            lr_num.text = str(logrotate.get('numToKeep', -1))
-            lr_adays = XML.SubElement(lr_xml, 'artifactDaysToKeep')
-            lr_adays.text = str(logrotate.get('artifactDaysToKeep', -1))
-            lr_anum = XML.SubElement(lr_xml, 'artifactNumToKeep')
-            lr_anum.text = str(logrotate.get('artifactNumToKeep', -1))
+            lr_xml = XML.SubElement(xml, "logRotator")
+            logrotate = data["logrotate"]
+            lr_days = XML.SubElement(lr_xml, "daysToKeep")
+            lr_days.text = str(logrotate.get("daysToKeep", -1))
+            lr_num = XML.SubElement(lr_xml, "numToKeep")
+            lr_num.text = str(logrotate.get("numToKeep", -1))
+            lr_adays = XML.SubElement(lr_xml, "artifactDaysToKeep")
+            lr_adays.text = str(logrotate.get("artifactDaysToKeep", -1))
+            lr_anum = XML.SubElement(lr_xml, "artifactNumToKeep")
+            lr_anum.text = str(logrotate.get("artifactNumToKeep", -1))
 
-        if 'raw' in data:
-            raw(parser, xml, data['raw'])
+        if "raw" in data:
+            raw(self.registry, xml, data["raw"])
 
 
-def raw(parser, xml_parent, data):
+def raw(registry, xml_parent, data):
     # documented in definition.rst since includes and docs is not working well
     # For cross cutting method like this
-    root = XML.fromstring(data.get('xml'))
+    root = XML.fromstring(data.get("xml"))
     remove_ignorable_whitespace(root)
     xml_parent.append(root)
